function createEnvironmentWrapper(outputFilename, quotedWrapperPath, environmentVariables, cluster)
% Create a script that sets the correct environment variables and then
% calls the job wrapper.

% Copyright 2023 The MathWorks, Inc.

dctSchedulerMessage(5, '%s: Creating environment wrapper at %s', mfilename, outputFilename);

% Open file in binary mode to make it cross-platform.
fid = fopen(outputFilename, 'w');
if fid < 0
    error('parallelexamples:GenericSLURM:FileError', ...
        'Failed to open file %s for writing', outputFilename);
end
fileCloser = onCleanup(@() fclose(fid));

% Specify shell to use
fprintf(fid, '#!/bin/sh\n');

formatSpec = 'export %s=''%s''\n';

% Write the commands to set and export environment variables
for ii = 1:size(environmentVariables, 1)
    fprintf(fid, formatSpec, environmentVariables{ii,1}, environmentVariables{ii,2});
end

if isprop(cluster.AdditionalProperties, 'AdditionalShellCommands') && ...
    ~isempty(cluster.AdditionalProperties.AdditionalShellCommands)
    asc = cluster.AdditionalProperties.AdditionalShellCommands;
    assert(isa(asc,'char') || isa(asc,'string') || isa(asc,'cell'), ...
        'Invalid datatype.  AdditionalShellCommands must be "char", "string", or "cell array".')
    if ~isa(cluster.AdditionalProperties.AdditionalShellCommands,'cell')
        asc = {cluster.AdditionalProperties.AdditionalShellCommands};
    end
    fprintf(fid, newline);
    fprintf(fid, '%s\n', asc{:});
end

% Add the location of the mpiLibConf.m file to the top of the MATLAB path
% to help support remote submission
fprintf(fid, 'export MATLABPATH=/cvmfs/software.hpc.rwth.de/Linux/RH8/x86_64/ISV/MATLAB/support_packages/matlab_parallel_server/scripts:$MATLABPATH');
fprintf(fid, newline);

% Write the command to run the job wrapper
fprintf(fid, '%s\n', quotedWrapperPath);

end
